# pyuptimerobot

[![codecov](https://codecov.io/gh/ludeeus/pyuptimerobot/branch/main/graph/badge.svg)](https://codecov.io/gh/ludeeus/pyuptimerobot)
![python version](https://img.shields.io/badge/Python-3.8=><=3.10-blue.svg)
[![PyPI](https://img.shields.io/pypi/v/pyuptimerobot)](https://pypi.org/project/pyuptimerobot)
![Actions](https://github.com/ludeeus/pyuptimerobot/workflows/Actions/badge.svg?branch=main)


_Python API wrapper for Uptime Robot_

## Installation

```bash
python3 -m pip install pyuptimerobot
```

Look at the file `example.py` for a usage example.

## Contribute

**All** contributions are welcome!

1. Fork the repository
2. Clone the repository locally and open the devcontainer or use GitHub codespaces
3. Do your changes
4. Lint the files with `make lint`
5. Ensure all tests passes with `make test`
6. Ensure 100% coverage with `make coverage`
7. Commit your work, and push it to GitHub
8. Create a PR against the `main` branch